==> PureCloudPlatformClientV2-160.0.4.tar.gz: PureCloudPlatformClientV2-160.0.4/PureCloudPlatformClientV2/apis/__init__.py <==
from __future__ import absolute_import

# import apis into api package
from .alerting_api import AlertingApi
from .analytics_api import AnalyticsApi
from .architect_api import ArchitectApi
from .audit_api import AuditApi
from .authorization_api import AuthorizationApi
from .billing_api import BillingApi
from .chat_api import ChatApi
from .coaching_api import CoachingApi
from .content_management_api import ContentManagementApi
from .conversations_api import ConversationsApi
from .data_extensions_api import DataExtensionsApi
from .downloads_api import DownloadsApi
from .events_api import EventsApi
from .external_contacts_api import ExternalContactsApi
from .fax_api import FaxApi
from .flows_api import FlowsApi
from .gamification_api import GamificationApi
from .general_data_protection_regulation_api import GeneralDataProtectionRegulationApi
from .geolocation_api import GeolocationApi
from .greetings_api import GreetingsApi
from .groups_api import GroupsApi
from .identity_provider_api import IdentityProviderApi
from .integrations_api import IntegrationsApi
from .journey_api import JourneyApi
from .knowledge_api import KnowledgeApi
from .language_understanding_api import LanguageUnderstandingApi
from .languages_api import LanguagesApi
from .learning_api import LearningApi
from .license_api import LicenseApi
from .locations_api import LocationsApi
from .messaging_api import MessagingApi
from .mobile_devices_api import MobileDevicesApi
from .notifications_api import NotificationsApi
from .o_auth_api import OAuthApi
from .objects_api import ObjectsApi
from .organization_api import OrganizationApi
from .organization_authorization_api import OrganizationAuthorizationApi
from .outbound_api import OutboundApi
from .presence_api import PresenceApi
from .process_automation_api import ProcessAutomationApi
from .quality_api import QualityApi
from .recording_api import RecordingApi
from .response_management_api import ResponseManagementApi
from .routing_api import RoutingApi
from .scim_api import SCIMApi
from .scripts_api import ScriptsApi
from .search_api import SearchApi
from .speech_text_analytics_api import SpeechTextAnalyticsApi
from .stations_api import StationsApi
from .suggest_api import SuggestApi
from .teams_api import TeamsApi
from .telephony_api import TelephonyApi
from .telephony_providers_edge_api import TelephonyProvidersEdgeApi
from .textbots_api import TextbotsApi
from .tokens_api import TokensApi
from .uploads_api import UploadsApi
from .usage_api import UsageApi
from .user_recordings_api import UserRecordingsApi
from .users_api import UsersApi
from .utilities_api import UtilitiesApi
from .voicemail_api import VoicemailApi
from .web_chat_api import WebChatApi
from .web_messaging_api import WebMessagingApi
from .web_deployments_api import WebDeploymentsApi
from .widgets_api import WidgetsApi
from .workforce_management_api import WorkforceManagementApi
from .alerting_api import AlertingApi
from .analytics_api import AnalyticsApi
from .architect_api import ArchitectApi
from .audit_api import AuditApi
from .authorization_api import AuthorizationApi
from .billing_api import BillingApi
from .chat_api import ChatApi
from .coaching_api import CoachingApi
from .content_management_api import ContentManagementApi
from .conversations_api import ConversationsApi
from .data_extensions_api import DataExtensionsApi
from .downloads_api import DownloadsApi
from .events_api import EventsApi
from .external_contacts_api import ExternalContactsApi
from .fax_api import FaxApi
from .flows_api import FlowsApi
from .gamification_api import GamificationApi
from .general_data_protection_regulation_api import GeneralDataProtectionRegulationApi
from .geolocation_api import GeolocationApi
from .greetings_api import GreetingsApi
from .groups_api import GroupsApi
from .identity_provider_api import IdentityProviderApi
from .integrations_api import IntegrationsApi
from .journey_api import JourneyApi
from .knowledge_api import KnowledgeApi
from .language_understanding_api import LanguageUnderstandingApi
from .languages_api import LanguagesApi
from .learning_api import LearningApi
from .license_api import LicenseApi
from .locations_api import LocationsApi
from .messaging_api import MessagingApi
from .mobile_devices_api import MobileDevicesApi
from .notifications_api import NotificationsApi
from .o_auth_api import OAuthApi
from .objects_api import ObjectsApi
from .organization_api import OrganizationApi
from .organization_authorization_api import OrganizationAuthorizationApi
from .outbound_api import OutboundApi
from .presence_api import PresenceApi
from .process_automation_api import ProcessAutomationApi
from .quality_api import QualityApi
from .recording_api import RecordingApi
from .response_management_api import ResponseManagementApi
from .routing_api import RoutingApi
from .scim_api import SCIMApi
from .scripts_api import ScriptsApi
from .search_api import SearchApi
from .speech_text_analytics_api import SpeechTextAnalyticsApi
from .stations_api import StationsApi
from .suggest_api import SuggestApi
from .teams_api import TeamsApi
from .telephony_api import TelephonyApi
from .telephony_providers_edge_api import TelephonyProvidersEdgeApi
from .textbots_api import TextbotsApi
from .tokens_api import TokensApi
from .uploads_api import UploadsApi
from .usage_api import UsageApi
from .user_recordings_api import UserRecordingsApi
from .users_api import UsersApi
from .utilities_api import UtilitiesApi
from .voicemail_api import VoicemailApi
from .web_chat_api import WebChatApi
from .web_messaging_api import WebMessagingApi
from .web_deployments_api import WebDeploymentsApi
from .widgets_api import WidgetsApi
from .workforce_management_api import WorkforceManagementApi

==> PureCloudPlatformClientV2-167.0.1.tar.gz: PureCloudPlatformClientV2-167.0.1/PureCloudPlatformClientV2/apis/__init__.py <==
from __future__ import absolute_import

# import apis into api package
from .alerting_api import AlertingApi
from .analytics_api import AnalyticsApi
from .architect_api import ArchitectApi
from .audit_api import AuditApi
from .authorization_api import AuthorizationApi
from .billing_api import BillingApi
from .chat_api import ChatApi
from .coaching_api import CoachingApi
from .content_management_api import ContentManagementApi
from .conversations_api import ConversationsApi
from .data_extensions_api import DataExtensionsApi
from .downloads_api import DownloadsApi
from .events_api import EventsApi
from .external_contacts_api import ExternalContactsApi
from .fax_api import FaxApi
from .flows_api import FlowsApi
from .gamification_api import GamificationApi
from .general_data_protection_regulation_api import GeneralDataProtectionRegulationApi
from .geolocation_api import GeolocationApi
from .greetings_api import GreetingsApi
from .groups_api import GroupsApi
from .identity_provider_api import IdentityProviderApi
from .infrastructure_as_code_api import InfrastructureAsCodeApi
from .integrations_api import IntegrationsApi
from .journey_api import JourneyApi
from .knowledge_api import KnowledgeApi
from .language_understanding_api import LanguageUnderstandingApi
from .languages_api import LanguagesApi
from .learning_api import LearningApi
from .license_api import LicenseApi
from .locations_api import LocationsApi
from .messaging_api import MessagingApi
from .mobile_devices_api import MobileDevicesApi
from .notifications_api import NotificationsApi
from .o_auth_api import OAuthApi
from .objects_api import ObjectsApi
from .organization_api import OrganizationApi
from .organization_authorization_api import OrganizationAuthorizationApi
from .outbound_api import OutboundApi
from .presence_api import PresenceApi
from .process_automation_api import ProcessAutomationApi
from .quality_api import QualityApi
from .recording_api import RecordingApi
from .response_management_api import ResponseManagementApi
from .routing_api import RoutingApi
from .scim_api import SCIMApi
from .scripts_api import ScriptsApi
from .search_api import SearchApi
from .speech_text_analytics_api import SpeechTextAnalyticsApi
from .stations_api import StationsApi
from .suggest_api import SuggestApi
from .teams_api import TeamsApi
from .telephony_api import TelephonyApi
from .telephony_providers_edge_api import TelephonyProvidersEdgeApi
from .textbots_api import TextbotsApi
from .tokens_api import TokensApi
from .uploads_api import UploadsApi
from .usage_api import UsageApi
from .user_recordings_api import UserRecordingsApi
from .users_api import UsersApi
from .utilities_api import UtilitiesApi
from .voicemail_api import VoicemailApi
from .web_chat_api import WebChatApi
from .web_messaging_api import WebMessagingApi
from .web_deployments_api import WebDeploymentsApi
from .widgets_api import WidgetsApi
from .workforce_management_api import WorkforceManagementApi
from .alerting_api import AlertingApi
from .analytics_api import AnalyticsApi
from .architect_api import ArchitectApi
from .audit_api import AuditApi
from .authorization_api import AuthorizationApi
from .billing_api import BillingApi
from .chat_api import ChatApi
from .coaching_api import CoachingApi
from .content_management_api import ContentManagementApi
from .conversations_api import ConversationsApi
from .data_extensions_api import DataExtensionsApi
from .downloads_api import DownloadsApi
from .events_api import EventsApi
from .external_contacts_api import ExternalContactsApi
from .fax_api import FaxApi
from .flows_api import FlowsApi
from .gamification_api import GamificationApi
from .general_data_protection_regulation_api import GeneralDataProtectionRegulationApi
from .geolocation_api import GeolocationApi
from .greetings_api import GreetingsApi
from .groups_api import GroupsApi
from .identity_provider_api import IdentityProviderApi
from .infrastructure_as_code_api import InfrastructureAsCodeApi
from .integrations_api import IntegrationsApi
from .journey_api import JourneyApi
from .knowledge_api import KnowledgeApi
from .language_understanding_api import LanguageUnderstandingApi
from .languages_api import LanguagesApi
from .learning_api import LearningApi
from .license_api import LicenseApi
from .locations_api import LocationsApi
from .messaging_api import MessagingApi
from .mobile_devices_api import MobileDevicesApi
from .notifications_api import NotificationsApi
from .o_auth_api import OAuthApi
from .objects_api import ObjectsApi
from .organization_api import OrganizationApi
from .organization_authorization_api import OrganizationAuthorizationApi
from .outbound_api import OutboundApi
from .presence_api import PresenceApi
from .process_automation_api import ProcessAutomationApi
from .quality_api import QualityApi
from .recording_api import RecordingApi
from .response_management_api import ResponseManagementApi
from .routing_api import RoutingApi
from .scim_api import SCIMApi
from .scripts_api import ScriptsApi
from .search_api import SearchApi
from .speech_text_analytics_api import SpeechTextAnalyticsApi
from .stations_api import StationsApi
from .suggest_api import SuggestApi
from .teams_api import TeamsApi
from .telephony_api import TelephonyApi
from .telephony_providers_edge_api import TelephonyProvidersEdgeApi
from .textbots_api import TextbotsApi
from .tokens_api import TokensApi
from .uploads_api import UploadsApi
from .usage_api import UsageApi
from .user_recordings_api import UserRecordingsApi
from .users_api import UsersApi
from .utilities_api import UtilitiesApi
from .voicemail_api import VoicemailApi
from .web_chat_api import WebChatApi
from .web_messaging_api import WebMessagingApi
from .web_deployments_api import WebDeploymentsApi
from .widgets_api import WidgetsApi
from .workforce_management_api import WorkforceManagementApi
